Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(394)

Unified Diff: chrome/browser/ui/views/tabs/tab_controller.h

Issue 983853002: Hide close buttons of inactive stacked tabs by default (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: histograms.xml changed Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/tabs/tab.cc ('k') | chrome/browser/ui/views/tabs/tab_strip.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/tabs/tab_controller.h
diff --git a/chrome/browser/ui/views/tabs/tab_controller.h b/chrome/browser/ui/views/tabs/tab_controller.h
index 5e26ecf27c9bebda0e5558027e219f0fe2e160a9..3e8807be7b45ea6864b425b352a0ef765a75122f 100644
--- a/chrome/browser/ui/views/tabs/tab_controller.h
+++ b/chrome/browser/ui/views/tabs/tab_controller.h
@@ -29,9 +29,9 @@ class TabController {
// Returns true if multiple selection is supported.
virtual bool SupportsMultipleSelection() = 0;
- // Returns true if we should force the close button of the inactive tab
- // |tab| to be hidden.
- virtual bool ShouldHideCloseButtonForInactiveTab(const Tab* tab) = 0;
+ // Returns true if we should force the close buttons of the inactive tabs
+ // to be hidden.
+ virtual bool ShouldHideCloseButtonForInactiveTabs() = 0;
// Selects the tab.
virtual void SelectTab(Tab* tab) = 0;
« no previous file with comments | « chrome/browser/ui/views/tabs/tab.cc ('k') | chrome/browser/ui/views/tabs/tab_strip.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698